Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon WorkLink.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon WorkLink - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon WorkLink

Amazon WorkLink (service prefix: `worklink` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon WorkLink
- Resource Types Defined by Amazon WorkLink
- Condition Keys for Amazon WorkLink

## Actions Defined by Amazon WorkLink

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateDomain | Grants permission to associate a domain with an Amazon WorkLink fleet | Write | fleet* |  |
AssociateWebsiteAuthorizationProvider | Grants permission to associate a website authorization provider with an Amazon WorkLink fleet | Write | fleet* |  |
AssociateWebsiteCertificateAuthority | Grants permission to associate a website certificate authority with an Amazon WorkLink fleet | Write | fleet* |  |
CreateFleet | Grants permission to create an Amazon WorkLink fleet | Write |  |  |
DeleteFleet | Grants permission to delete an Amazon WorkLink fleet | Write | fleet* |  |
DescribeAuditStreamConfiguration | Grants permission to describe the audit stream configuration for an Amazon WorkLink fleet | Read | fleet* |  |
DescribeCompanyNetworkConfiguration | Grants permission to describe the company network configuration for an Amazon WorkLink fleet | Read | fleet* |  |
DescribeDevice | Grants permission to describe details of a device associated with an Amazon WorkLink fleet | Read | fleet* |  |
DescribeDevicePolicyConfiguration | Grants permission to describe the device policy configuration for an Amazon WorkLink fleet | Read | fleet* |  |
DescribeDomain | Grants permission to describe details about a domain associated with an Amazon WorkLink fleet | Read | fleet* |  |
DescribeFleetMetadata | Grants permission to describe metadata of an Amazon WorkLink fleet | Read | fleet* |  |
DescribeIdentityProviderConfiguration | Grants permission to describe the identity provider configuration for an Amazon WorkLink fleet | Read | fleet* |  |
DescribeWebsiteCertificateAuthority | Grants permission to describe a website certificate authority associated with an Amazon WorkLink fleet | Read | fleet* |  |
DisassociateDomain | Grants permission to disassociate a domain from an Amazon WorkLink fleet | Write | fleet* |  |
DisassociateWebsiteAuthorizationProvider | Grants permission to disassociate a website authorization provider from an Amazon WorkLink fleet | Write | fleet* |  |
DisassociateWebsiteCertificateAuthority | Grants permission to disassociate a website certificate authority from an Amazon WorkLink fleet | Write | fleet* |  |
ListDevices | Grants permission to list the devices associated with an Amazon WorkLink fleet | List | fleet* |  |
ListDomains | Grants permission to list the associated domains for an Amazon WorkLink fleet | List | fleet* |  |
ListFleets | Grants permission to list the Amazon WorkLink fleets associated with the account | List |  |  |
ListWebsiteAuthorizationProviders | Grants permission to list the website authorization providers for an Amazon WorkLink fleet | List | fleet* |  |
ListWebsiteCertificateAuthorities | Grants permission to list the website certificate authorities associated with an Amazon WorkLink fleet | List | fleet* |  |
RestoreDomainAccess | Grants permission to restore access to a domain associated with an Amazon WorkLink fleet | Write | fleet* |  |
RevokeDomainAccess | Grants permission to revoke access to a domain associated with an Amazon WorkLink fleet | Write | fleet* |  |
SignOutUser | Grants permission to sign out a user from an Amazon WorkLink fleet | Write | fleet* |  |
UpdateAuditStreamConfiguration | Grants permission to update the audit stream configuration for an Amazon WorkLink fleet | Write | fleet* |  |
UpdateCompanyNetworkConfiguration | Grants permission to update the company network configuration for an Amazon WorkLink fleet | Write | fleet* |  |
UpdateDevicePolicyConfiguration | Grants permission to update the device policy configuration for an Amazon WorkLink fleet | Write | fleet* |  |
UpdateDomainMetadata | Grants permission to update the metadata for a domain associated with an Amazon WorkLink fleet | Write | fleet* |  |
UpdateFleetMetadata | Grants permission to update the metadata of an Amazon WorkLink fleet | Write | fleet* |  |
UpdateIdentityProviderConfiguration | Grants permission to update the identity provider configuration for an Amazon WorkLink fleet | Write | fleet* |  |

## Resource Types Defined by Amazon WorkLink

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
fleet | `arn:$ { Partition}:worklink::$ { Account}:fleet/$ { fleetName}` |

## Condition Keys for Amazon WorkLink

WorkLink has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .